import { jsx as _jsx } from "react/jsx-runtime";
import hoistNonReactStatics from 'hoist-non-react-statics';
import { DevCycleProvider, useDevCycleClient } from '@devcycle/react-client-sdk';
import React from 'react';
/**
 * Component which runs a one-time sync of the server's boostrap data to the client's DevCycleClient
 * @param devcycleSSR
 * @param children
 * @constructor
 */
const BootstrapSync = ({ devcycleSSR, children, }) => {
    var _a;
    const client = useDevCycleClient();
    const [isInitialized, setIsInitialized] = React.useState(false);
    if (!isInitialized) {
        client.synchronizeBootstrapData(devcycleSSR.bucketedConfig, devcycleSSR.user, (_a = devcycleSSR.userAgent) !== null && _a !== void 0 ? _a : undefined);
        setIsInitialized(true);
    }
    return children;
};
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export const appWithDevCycle = (WrappedComponent, additionalOptions = {}) => {
    const AppWithDevCycle = (props) => {
        const devcycleSSR = props.pageProps
            ._devcycleSSR;
        const onServerside = typeof window === 'undefined';
        if (!devcycleSSR) {
            return _jsx(WrappedComponent, { ...props });
        }
        return (_jsx(DevCycleProvider, { config: {
                sdkKey: devcycleSSR.sdkKey,
                options: {
                    ...additionalOptions,
                    deferInitialization: true,
                    disableAutomaticEventLogging: onServerside,
                    disableCustomEventLogging: onServerside,
                    disableRealtimeUpdates: onServerside,
                    disableConfigCache: true,
                    next: {},
                },
            }, children: _jsx(BootstrapSync, { devcycleSSR: devcycleSSR, children: _jsx(WrappedComponent, { ...props }) }) }));
    };
    return hoistNonReactStatics(AppWithDevCycle, WrappedComponent);
};
//# sourceMappingURL=appWithDevCycle.js.map