import { DVCPopulatedUser } from '@devcycle/js-client-sdk';
import { generateBucketedConfig } from '@devcycle/bucketing';
import { sseURlGetter } from '../server/ably.js';
const getFetchUrl = (sdkKey) => `https://config-cdn.devcycle.com/config/v1/client/${sdkKey}.json`;
export const fetchCDNConfig = async (sdkKey) => {
    return await fetch(getFetchUrl(sdkKey));
};
export const getBucketedConfig = async (sdkKey, user, userAgent) => {
    var _a;
    const configResponse = await fetchCDNConfig(sdkKey);
    if (!configResponse.ok) {
        throw new Error('Could not fetch config');
    }
    const config = await configResponse.json();
    const populatedUser = new DVCPopulatedUser(user, {}, undefined, undefined, userAgent !== null && userAgent !== void 0 ? userAgent : undefined);
    const bucketedConfig = generateBucketedConfig({
        user: populatedUser,
        config,
    });
    for (const feature of Object.values(bucketedConfig.features)) {
        if (feature.settings === undefined) {
            // next complains about not being able to serialize explicitly undefined values
            delete feature.settings;
        }
    }
    return {
        config: {
            ...bucketedConfig,
            sse: {
                url: await sseURlGetter(sdkKey, (_a = config.ably) === null || _a === void 0 ? void 0 : _a.apiKey)(),
                inactivityDelay: 1000 * 60 * 2,
            },
        },
    };
};
//# sourceMappingURL=bucketing.js.map