import { fetchCDNConfig } from './requests';
import { generateBucketedConfig } from '@devcycle/bucketing';
import { cache } from 'react';
import { DVCPopulatedUser } from '@devcycle/js-client-sdk';
import { sseURlGetter } from './ably';
// wrap this function in react cache to avoid redoing work for the same user and config
const generateBucketedConfigCached = cache(async (sdkKey, user, configResponse, userAgent) => {
    var _a;
    const config = await configResponse.json();
    const populatedUser = new DVCPopulatedUser(user, {}, undefined, undefined, userAgent !== null && userAgent !== void 0 ? userAgent : undefined);
    return {
        config: {
            ...generateBucketedConfig({ user: populatedUser, config }),
            sse: {
                url: await sseURlGetter(sdkKey, (_a = config.ably) === null || _a === void 0 ? void 0 : _a.apiKey)(),
                inactivityDelay: 1000 * 60 * 2,
            },
        },
    };
});
/**
 * Retrieve the config from CDN for the current request's SDK Key. This data will often be cached
 * Compute the bucketed config for the current request's user using that data, with local bucketing library
 * Cache the bucketed config for this request so that repeated calls to this function are memoized
 */
export const getBucketedConfig = async (sdkKey, user, userAgent) => {
    var _a;
    // this request will be cached by Next
    const cdnConfig = await fetchCDNConfig(sdkKey);
    if (!cdnConfig.ok) {
        const responseText = await cdnConfig.text();
        throw new Error('Could not fetch config: ' + responseText);
    }
    const { config } = await generateBucketedConfigCached(sdkKey, user, cdnConfig, userAgent);
    return {
        ...config,
        lastModified: (_a = cdnConfig.headers.get('last-modified')) !== null && _a !== void 0 ? _a : undefined,
    };
};
//# sourceMappingURL=bucketing.js.map